<?php
namespace SEOQCore\Widgets;

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Brand_Slider extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'seoq_brand_slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Brand Slider', 'seoq-core' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'seoq-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'seoq_core' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'seoq-core' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'seoq_brand_section',
            [
                'label' => __( 'Brand Item', 'seoq-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

		$this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Trusted by 25,000+ companies', 'seoq-core'),
                'placeholder' => esc_html__('Type Heading Text', 'seoq-core'),
                'label_block' => true,
            ]
        );

		$this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'seoq_brand_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Image', 'seoq-core' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'seoq_brand_url',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'label' => __( 'URL', 'seoq-core' ),
                'default' => __( '#', 'seoq-core' ),
                'placeholder' => __( 'Type url here', 'seoq-core' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'seoq_brand_slides',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => esc_html__( 'Brand Item', 'seoq-core' ),
                'default' => [
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'seoq_brand_image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ]
            ]
        );

        $this->end_controls_section();

		$this->start_controls_section(
			'seoq_brand_style',
			[
				'label' => __( 'Brand Item', 'seoq-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_control(
			'_title_heading',
			[
				'label' => esc_html__( 'Title', 'text-domain' ),
				'type' => Controls_Manager::HEADING,
			]
		);

		$this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .brand-one__title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'text-domain' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .brand-one__title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .brand-one__title',
            ]
        );

		$this->add_control(
			'_slider_heading',
			[
				'label' => esc_html__( 'Brand Slider', 'text-domain' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->start_controls_tabs( 'brand_slider_tabs' );
		
		$this->start_controls_tab(
			'brand_slider_normal_tab',
			[
				'label' => esc_html__( 'Normal', 'text-domain' ),
			]
		);
		
		$this->add_control(
			'brand_slider_opacity',
			[
				'label'             => esc_html__( 'Opacity', 'seoq-core' ),
				'type'              => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min'       => .1,
						'max'       => 1,
						'step'      => .1,
					],
				],
				'default' => [
					'size'          => .4,
				],
				'selectors' => [
					'{{WRAPPER}} .brand-one__single a img' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->start_controls_tab(
			'brand_slider_hover_tab',
			[
				'label' => esc_html__( 'Hover', 'text-domain' ),
			]
		);
		
		$this->add_control(
			'brand_slider_opacity_hover',
			[
				'label'             => esc_html__( 'Opacity', 'seoq-core' ),
				'type'              => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min'       => .1,
						'max'       => 1,
						'step'      => .1,
					],
				],
				'default' => [
					'size'          => 1,
				],
				'selectors' => [
					'{{WRAPPER}} .brand-one__single a:hover img' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->end_controls_tab();
		
		$this->end_controls_tabs();

        $this->end_controls_section();
		
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute('title_args', 'class', 'brand-one__title');

		?>

			<div class="brand-one pt-80 pb-140 wow fadeInUp" data-wow-delay=".3s">
				<div class="container">
					<div class="row">
						<?php
							if ( !empty($settings['seoq_title' ]) ) :
								printf( '<%1$s %2$s>%3$s</%1$s>',
									tag_escape( $settings['seoq_title_tag'] ),
									$this->get_render_attribute_string( 'title_args' ),
									rrdevs_kses( $settings['seoq_title' ] )
									);
							endif;
						?>
					</div>
					<div class="row justify-content-center">
						<div class="col-xl-10">
							<div class="brand-one__active owl-carousel">
								<?php foreach ($settings['seoq_brand_slides'] as $item) : 
									if ( !empty($item['seoq_brand_image']['url']) ) {
										$seoq_brand_image_url = !empty($item['seoq_brand_image']['id']) ? wp_get_attachment_image_url( $item['seoq_brand_image']['id']) : $item['seoq_brand_image']['url'];
										$seoq_brand_image_alt = get_post_meta($item["seoq_brand_image"]["id"], "_wp_attachment_image_alt", true);
									}
									?>
									<div class="brand-one__single">
										<a href="#"><img src="<?php echo esc_url($seoq_brand_image_url); ?>" alt="<?php echo esc_url($seoq_brand_image_alt); ?>"></a>
									</div>
								<?php endforeach; ?>
							</div>
						</div>
					</div>
				</div>
			</div>

		<?php
	}
}

$widgets_manager->register( new seoq_Brand_Slider() );