<?php

namespace SEOQCore\Widgets;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;

if ( !defined( 'ABSPATH' ) ) {
    exit;
}
// Exit if accessed directly

/**
 * SEOQ Core
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class SEOQ_Portfolio extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'seoq_portfolio';
    }

    /**
     * Retrieve the widget title.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Portfolio', 'seoq-core' );
    }

    /**
     * Retrieve the widget icon.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'seoq-icon';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return ['seoq_core'];
    }

    /**
     * Retrieve the list of scripts the widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.0.0
     *
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends() {
        return ['seoq-portfolio'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function register_controls() {

        // Project group
        $this->start_controls_section(
            'seoq_portfolio',
            [
                'label'       => esc_html__( 'Portfolio', 'seoq-core' ),
                'description' => esc_html__( 'Control all the style settings from Style tab', 'seoq-core' ),
                'tab'         => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'seoq_title',
            [
                'label' => esc_html__('Title', 'seoq-core'),
                'description' => seoq_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXT,
                'default' => __('Real-Life Case <br> Studies That Inspire.', 'seoq-core'),
                'placeholder' => esc_html__('Type Section Title Here', 'seoq-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'seoq_title_tag',
            [
                'label' => esc_html__('Title HTML Tag', 'seoq-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1' => [
                        'title' => esc_html__('H1', 'seoq-core'),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2' => [
                        'title' => esc_html__('H2', 'seoq-core'),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3' => [
                        'title' => esc_html__('H3', 'seoq-core'),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4' => [
                        'title' => esc_html__('H4', 'seoq-core'),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5' => [
                        'title' => esc_html__('H5', 'seoq-core'),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6' => [
                        'title' => esc_html__('H6', 'seoq-core'),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_control(
            'important_note',
            [
                'type'            => Controls_Manager::RAW_HTML,
                'raw'             => esc_html__( 'Add photos from Dashboard Portfolio.', 'seoq-core' ),
                'content_classes' => 'elementor-panel-alert elementor-panel-alert-danger',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_layout_stylesheet',
            [
                'label' => esc_html__( 'Layout', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_layout_background',
            [
                'label' => esc_html__( 'Background', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .project-area' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'content_layout_padding',
            [
                'label'      => esc_html__( 'Padding', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .project-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        // Title
        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'seoq-core' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'seoq-core' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'seoq-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title__two-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .section-title__two-title',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'portfolio_stylesheet',
            [
                'label' => esc_html__( 'Portfolio', 'seoq-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'filter_tooltip_heading',
            [
                'label' => esc_html__( 'Filter Active', 'seoq-core' ),
                'type'  => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'filter_tooltip_color',
            [
                'label' => esc_html__( 'Color', 'text-domain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button .short-message span' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'filter_tooltip_background',
            [
                'label' => esc_html__( 'Background', 'text-domain' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button .short-message span' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .portfolio-menu button .short-message span:after' => 'border-color: {{VALUE}} transparent transparent transparent',
                ],
            ]
        );

        $this->add_control(
            'filter_options',
            [
                'label' => esc_html__( 'Filter Options', 'seoq-core' ),
                'type'  => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( 'tabs_filter' );

        $this->start_controls_tab(
            'filter_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'filter_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'filter_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'filter_color_hover',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'filter_active_tab',
            [
                'label' => esc_html__( 'Active', 'seoq-core' ),
            ]
        );

        $this->add_control(
            'filter_color_active',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-menu button.active' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_control(
            'filter_bottom_spacing',
            [
                'label'      => esc_html__( 'Bottom Spacing', 'seoq-core' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .section-title__column-two' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            '_heading_layout',
            [
                'label'     => esc_html__( 'Layout', 'seoq-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        
        $this->add_control(
            'portfolio_layout_border_color',
            [
                'label'     => esc_html__( 'Border Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio__single-content p:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->start_controls_tabs( '_portfolio_layout_tabs' );
        
        $this->start_controls_tab(
            'portfolio_layout_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'text-domain' ),
            ]
        );
        
        $this->add_control(
            'portfolio_layout_color',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio__single-content h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'portfolio_layout_background',
            [
                'label'     => esc_html__( 'Background', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio__single-content' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'portfolio_layout_hover_tab',
            [
                'label' => esc_html__( 'Hover', 'text-domain' ),
            ]
        );
        
        $this->add_control(
            'portfolio_layout_color_hover',
            [
                'label'     => esc_html__( 'Color', 'seoq-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .portfolio__single-content h3:hover a' => 'color: {{VALUE}}',
                ],
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();

        $this->add_control(
            'portfolio_layout_border_radius',
            [
                'label'      => esc_html__( 'Border Radius', 'seoq-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .portfolio__single' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .portfolio__single-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('title_args', 'class', 'section-title__two-title');

        $tags = get_terms( [
            'hide_empty' => true,
            'taxonomy'   => 'portfolio-cat',
        ] );

        $portfolios = new \WP_Query( [
            'posts_per_page' => -1,
            'post_type'      => 'portfolio',
            'post_status'    => 'publish',

        ] );

        ?>

            <div class="project-area pt-110 pb-110">
                <div class="container">
                    <div class="row">
                        <div class="section-title__column-two mb-50 wow fadeInUp" data-wow-delay=".3s">
                            <?php
                                if ( !empty($settings['seoq_title' ]) ) :
                                    printf( '<%1$s %2$s>%3$s</%1$s>',
                                        tag_escape( $settings['seoq_title_tag'] ),
                                        $this->get_render_attribute_string( 'title_args' ),
                                        rrdevs_kses( $settings['seoq_title' ] )
                                        );
                                endif;
                            ?>
                            <div class="section-title__two-right">
                                <div class="portfolio-menu">
                                    <button class="active" data-filter="*">
                                        <span class="short-message">
                                            <span>New</span>
                                        </span>
                                        All
                                    </button>
                                    <?php
                                        foreach ( $tags as $tag ) {
                                            printf( '<button data-filter=".%s">%s</button>', esc_attr( $tag->slug ), esc_html( $tag->name ) );
                                        }
                                    ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row portfolio-active">
                        <?php while ( $portfolios->have_posts() ) {
                            $portfolios->the_post();
                            $portfolio_tags = $this->get_portfolio_tags( get_the_ID() );
                            $image_url = get_the_post_thumbnail_url( get_the_ID(), 'large' )
                            ?>
                            <div class="col-xl-4 col-lg-4 col-md-6 <?php echo esc_attr( $portfolio_tags ); ?> wow fadeInUp" data-wow-delay=".3s">
                                <div class="portfolio__single bg-property mb-30" data-background="<?php the_post_thumbnail_url( 'large' );?>">
                                    <div class="portfolio__single-content">
                                        <span><?php echo the_excerpt(); ?></span>
                                        <h3><a href="<?php the_permalink(); ?>"><?php the_title() ; ?></a></h3>
                                    </div>
                                </div>
                            </div>
                            <?php
                        }?>
                    </div>
                </div>
            </div>

	    <?php wp_reset_query();?>

        <?php
}

    function get_portfolio_tags( $post_id ) {
        $tags = get_the_terms( $post_id, 'portfolio-cat' );
        $_tags = [];

        if ( !empty( $tags ) ) {

            foreach ( $tags as $tag ) {
                $_tags[$tag->term_id] = $tag->slug;
            }
        }

        return join( ' ', $_tags );
    }
}

$widgets_manager->register( new SEOQ_Portfolio() );