<?php
namespace SEOQCore;

use SEOQCore\PageSettings\Page_Settings;
use Elementor\Controls_Manager;


/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class SEOQ_Core_Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Add Category
	 */

    public function seoq_core_elementor_category($manager)
    {
        $manager->add_category(
            'seoq_core',
            array(
                'title' => esc_html__('SEOQ Core Addons', 'seoq-core'),
                'icon' => 'eicon-banner',
            )
        );
    }

	/**
	 * widget_styles
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_styles() {
		wp_enqueue_style('seoq-core', SEOQ_CORE_ADDONS_URL . 'assets/css/seoq-core.css', null, '1.0');
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_enqueue_script( 'seoq-core', plugins_url( '/assets/js/hello-world.js', __FILE__ ), [ 'jquery' ], false, true );
	}

	/**
	 * Editor scripts
	 *
	 * Enqueue plugin javascripts integrations for Elementor editor.
	 *
	 * @since 1.2.1
	 * @access public
	 */
	public function editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'editor_scripts_as_a_module' ], 10, 2 );

		wp_enqueue_script(
			'seoq_core-editor',
			plugins_url( '/assets/js/editor/editor.js', __FILE__ ),
			[
				'elementor-editor',
			],
			'1.2.1',
			true
		);
	}


	/**
	 * seoq_enqueue_editor_scripts
	 */
    function seoq_enqueue_editor_scripts()
    {
        wp_enqueue_style('seoq-element-addons-editor', SEOQ_CORE_ADDONS_URL . 'assets/css/editor.css', null, '1.0');
    }

	/**
	 * Force load editor script as a module
	 *
	 * @since 1.2.1
	 *
	 * @param string $tag
	 * @param string $handle
	 *
	 * @return string
	 */
	public function editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'seoq-core-editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @param Widgets_Manager $widgets_manager Elementor widgets manager.
	 */
	public function register_widgets( $widgets_manager ) {
		// Its is now safe to include Widgets files
		foreach($this->seoq_core_widget_list() as $widget_file_name){
			require_once( SEOQ_CORE_ELEMENTS_PATH . "/{$widget_file_name}.php" );
		}
	}

	public function seoq_core_widget_list() {
		return [
			'advanced-tab',
			'heading',
			'hero',
			'about',
			'services',
			'service-list',
			'info-list',
			'portfolio',
			'tab-info',
			'promotion',
			'team',
			'case-study-slider',
			'team-details',
			'pricing',
			'features',
			'testimonial-slider',
			'post-list',
			'gallery-info',
			'faq',
			'skill',
			'fun-fact',
			'video-popup',
			'brand',
			'brand-slider',
			'image',
			'horizontal-accordion',
			'cta',
			'contact-info',
			'contact-form',
			'info-point',
			'seoq-btn',
			'integrations',
			'scroll-card',
		];
	}

	/**
	 * Add page settings controls
	 *
	 * Register new settings for a document page settings.
	 *
	 * @since 1.2.1
	 * @access private
	 */
	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/manager.php' );
		new Page_Settings();
	}

	/**
	 * Register controls
	 *
	 * @param Controls_Manager $controls_Manager
	 */

    public function register_controls(Controls_Manager $controls_Manager)
    {
        include_once(SEOQ_CORE_ADDONS_DIR . '/controls/seoqgradient.php');
        $seoqgradient = 'SEOQCore\Elementor\Controls\Group_Control_SEOQGradient';
        $controls_Manager->add_group_control($seoqgradient::get_type(), new $seoqgradient());

        include_once(SEOQ_CORE_ADDONS_DIR . '/controls/seoqbggradient.php');
        $seoqbggradient = 'SEOQCore\Elementor\Controls\Group_Control_SEOQBGGradient';
        $controls_Manager->add_group_control($seoqbggradient::get_type(), new $seoqbggradient());
    }

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {

        add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'widget_styles' ] );
        add_action( 'elementor/frontend/after_enqueue_scripts', [ $this, 'widget_scripts' ] );

		add_action( 'elementor/widgets/register', [ $this, 'register_widgets' ] );

		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'editor_scripts' ] );

		add_action('elementor/elements/categories_registered', [$this, 'seoq_core_elementor_category']);

	    add_action('elementor/controls/controls_registered', [$this, 'register_controls']);

	    add_action('elementor/editor/after_enqueue_scripts', [$this, 'seoq_enqueue_editor_scripts'] );

		$this->add_page_settings_controls();

	}
}

// Instantiate Plugin Class
SEOQ_Core_Plugin::instance();